import React from 'react';
import Badge from '../badge/Badge';
import Button from '../button/Button';
import List, { ListItemProps } from '../list/List';
import Popover from '../popover/Popover';
import './notification.scss';
declare type ExtendProps = {
    [key: string]: any;
};
interface NotificationTranslation {
    title?: string;
    all?: string;
    unread?: string;
    showMore?: string;
    markAll?: string;
    empty?: string;
}
declare type FilterMode = 'all' | 'unread';
export interface NotificationItem extends ExtendProps {
    id: string | number;
    title?: React.ReactNode;
    time?: Date | string | React.ReactNode;
    unread?: boolean;
    avt?: React.ReactNode;
    link?: string;
    listItemProps?: Partial<ListItemProps>;
}
export declare type NotificationList = Array<{
    id: string | number;
    group?: React.ReactNode;
    list: Array<NotificationItem>;
}>;
export interface NotificationProps {
    IconProps?: Partial<React.ComponentProps<typeof Button>>;
    BadgeProps?: Partial<React.ComponentProps<typeof Badge>>;
    PopoverProps?: Partial<React.ComponentProps<typeof Popover>>;
    ListProps?: Partial<React.ComponentProps<typeof List>>;
    unreadCount?: number;
    items?: NotificationList;
    hideReadAll?: boolean;
    hideShowMore?: boolean;
    hideFilter?: boolean;
    hideAvt?: boolean;
    /** Custom filter group */
    filter?: React.ReactNode;
    /** Custom show more group */
    bottomAction?: React.ReactNode;
    /** Change language */
    translation?: NotificationTranslation;
    onItemClick?: (item: NotificationItem) => any;
    onFilterChange?: (mode: FilterMode) => any;
    onMarkAllAsRead?: () => any;
    onMoreBtnClick?: () => any;
}
export declare const Notification: React.FC<NotificationProps>;
export default Notification;
